@@ -1,3 +1,4 @@
+import sys
 import unittest
 from isoweek import Week
 
@@ -112,8 +113,9 @@ class TestWeek(unittest.TestCase):
         self.assertEqual(str(w + 0),   "2011W20")
         self.assertEqual(str(w + 1),   "2011W21")
         self.assertEqual(str(w - 1),   "2011W19")
-        self.assertEqual(str(w + 1L),  "2011W21")
-        self.assertEqual(str(w - 1L),  "2011W19")
+        if sys.version < '3':
+            self.assertEqual(str(w + long(1)),  "2011W21")
+            self.assertEqual(str(w - long(1)),  "2011W19")
         self.assertEqual(str(w + 52),  "2012W20")
         self.assertEqual(str(w - 104), "2009W21")
 
